# Slot: identifier


True means that this slot must be unique across the collection of slots

URI: [http://w3id.org/biolink/biolinkml/meta/identifier](slot_uri)
## Domain and Range

[SlotDefinition](SlotDefinition.md) -><sub>opt</sub> [Boolean](Boolean.md)
## Inheritance

## Children

## Used by

 * [SlotDefinition](SlotDefinition.md)
